@@ -45,8 +45,14 @@ def configure():
         if not pages:
             logger.info("Loading %s" % initialData)
             try:
-                call_command('cms_loaddata', initialData)
-                logger.info('Load cms data success.')
+                # 不知為啥使用 call_command 時 logging 會有 cp950 error
+                result = os.system('python manage.py cms_loaddata %s' % initialData)
+                if result == 0:
+                    logger.info('Load cms data success.')
+                else:
+                    logger.info(
+                        "cms_loaddata error: "
+                        "please try 'python manage.py cms_loaddata %s' to check error." % initialData)
             except Exception as e:
                 logger.info("cms_loaddata error: %s" % str(e))
         else:
@@ -74,10 +80,15 @@ def configure():
             
             logger.info("Loading initial cms data...")
             try:
-                call_command(
-                    'cms_loaddata', 
-                    'initial_data_%s.json' % (_SERVER_MODE, ))
-                logger.info('Load cms data success.')
+                
+                result = os.system(
+                    'python manage.py cms_loaddata %s' % updatedCmsDataPath)
+                if result == 0:
+                    logger.info('Load cms data success.')
+                else:
+                    logger.info(
+                        "cms_loaddata error: "
+                        "please try 'python manage.py cms_loaddata %s' to check error." % updatedCmsDataPath)
             except Exception as e:
                 logger.info("cms_loaddata error: %s" % str(e))
         else:
