@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_loaddata.py 11488 2019-04-24 06:00:14Z Lavender $
+# $Id: cms_loaddata.py 12280 2020-05-28 08:02:42Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-04-24 14:00:14 +0800 (週三, 24 四月 2019) $
-# $Revision: 11488 $
+# $Date: 2020-05-28 17:02:42 +0900 (週四, 28 五月 2020) $
+# $Revision: 12280 $
 
 import json
 
@@ -33,7 +33,7 @@ class Command(BaseCommand):
         dataJson = options['data']
         call_command('loaddata', dataJson)  
 
-        with open(dataJson) as data:
+        with open(dataJson, encoding="utf-8") as data:
             allData = json.loads(data.read())
 
         imageData = \
